"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pruneOutlookElement = exports.pruneGmailElement = void 0;
const DUMMY_QR_CODE_ID = "dummyQrCode";
const deleteAttributesWithPrefix = (element, prefix) => {
    for (const attribute of element.attributes) {
        if (attribute.name.includes(prefix)) {
            element.removeAttribute(attribute.name);
        }
    }
};
const deleteDataAttributes = (element) => {
    deleteAttributesWithPrefix(element, "data-");
};
const isDummyQrCode = (element) => {
    if (element.id === DUMMY_QR_CODE_ID) {
        return true;
    }
};
exports.pruneGmailElement = (element) => {
    if (isDummyQrCode(element)) {
        return true;
    }
    if (element.attributes.length > 0) {
        for (const attribute of element.attributes) {
            if (attribute.name === "data-surl") {
                element.setAttribute("src", attribute.value);
            }
        }
        deleteDataAttributes(element);
    }
    return false;
};
/**
 * Returns true if element should be completely removed
 * @param element
 */
exports.pruneOutlookElement = (element) => {
    if (isDummyQrCode(element)) {
        return true;
    }
    // Remove Outlook generic <o:p> tags
    if (element.nodeName.toLowerCase().startsWith("o:")) {
        return true;
    }
    if (element.attributes.length > 0) {
        deleteDataAttributes(element);
        // TODO Prepare for demo. fix later. the value at style attribute is changed (additional spaces and semicolon)
        element.removeAttribute("style");
        // There is an issue with id attribute which contains id like id="some id here" converted to id="some"
        element.removeAttribute("id");
        if (element.nodeName.toLowerCase() === "img") {
            element.removeAttribute("contextid");
            element.removeAttribute("contenttype");
            element.removeAttribute("unselectable");
            element.removeAttribute("aria-haspopup");
        }
        if (element.nodeName.toLowerCase() === "span") {
            element.removeAttribute("role");
            element.removeAttribute("target");
        }
        deleteDataAttributes(element);
        deleteAttributesWithPrefix(element, "aria-");
        for (const attribute of element.attributes) {
            let valueSplit = attribute.value.split(" ");
            valueSplit = valueSplit.map((value) => value.startsWith("x_") ? value.replace("x_", "") : value);
            element.setAttribute(attribute.name, valueSplit.join(" "));
        }
    }
    return false;
};
