import axios from "axios";
import { BlockData, TxData, TxMerkleTreeData } from "../types";

class AeternityService {
  private _nodeUrl = "";
  private _compilerUrl = "";
  private _contractBytecode = "";

  constructor(nodeUrl: string, compilerUrl: string, contractBytecode: string) {
    this._nodeUrl = nodeUrl;
    this._compilerUrl = compilerUrl;
    this._contractBytecode = contractBytecode;

    if (!nodeUrl) {
      throw new Error("Aeternity node URL not defined");
    }

    if (!compilerUrl) {
      throw new Error("Aeternity compiler URL not defined");
    }

    if (!contractBytecode) {
      throw new Error("Aeternity contract bytecode not defined");
    }
  }

  async getTxDataByHash(hash: string): Promise<TxData> {
    const { data } = await axios(`${this._nodeUrl}/v2/transactions/${hash}`);

    return {
      hash: data.hash,
      blockHeight: data.block_height,
      tx: {
        callData: data.tx.call_data,
      },
    };
  }

  async decodeContractCallData(callData: string): Promise<TxMerkleTreeData> {
    const { data } = await axios({
      url: `${this._compilerUrl}/decode-calldata/bytecode/`,
      method: "POST",
      headers: {
        "Content-Type": "application/json",
      },
      data: {
        calldata: callData,
        bytecode: this._contractBytecode,
      },
    });

    return {
      merkleeTreeFileName: data.arguments[0]?.value[0]?.key?.value,
      rootNodeHash: data.arguments[0]?.value[0]?.val?.value,
    };
  }

  async getBlockData(height: number): Promise<BlockData> {
    const [blockInfo, blockchainHeight] = await Promise.all([
      axios(`${this._nodeUrl}/v2/key-blocks/height/${height}`).then(
        ({ data }) => data
      ),
      this.getBlockhainHeight(),
    ]);

    return {
      blockHeight: blockInfo.height,
      timestamp: blockInfo.time,
      confirmationsAmount: blockchainHeight - blockInfo.height,
    };
  }

  async getBlockhainHeight(): Promise<number> {
    const { data } = await axios(
      `${this._nodeUrl}/v2/key-blocks/current/height`
    );
    return data.height;
  }
}

export default AeternityService;
